==> flutter_webview_desktop-0.0.3-dev.tar.gz: lib/src/desktop_webview_platform_controller.dart <==
import 'dart:async';
import 'dart:ui';

import 'package:flutter/gestures.dart';
import 'package:webview_flutter_platform_interface/webview_flutter_platform_interface.dart';

import 'desktop_webview_controller.dart';
import 'desktop_webview_enums.dart';

DesktopMousePointerButton getDesktopButton(int value) {
  switch (value) {
    case kPrimaryMouseButton:
      return DesktopMousePointerButton.primary;
    case kSecondaryMouseButton:
      return DesktopMousePointerButton.secondary;
    case kTertiaryButton:
      return DesktopMousePointerButton.tertiary;
    default:
      return DesktopMousePointerButton.none;
  }
}

class DesktopWebviewController implements WebViewPlatformController {
  DesktopWebviewController(this._javascriptChannelRegistry) {
    _webview = DesktopWebview(_javascriptChannelRegistry);
  }
  late DesktopWebview _webview;
  final JavascriptChannelRegistry _javascriptChannelRegistry;
  @override
  Future<void> addJavascriptChannels(Set<String> javascriptChannelNames) {
    return _webview.addJavascriptChannels(javascriptChannelNames);
  }

  @override
  Future<bool> canGoBack() {
    return _webview.canGoBack;
  }

  @override
  Future<bool> canGoForward() {
    return _webview.canGoForward;
  }

  @override
  Future<void> clearCache() {
    return _webview.clearCache();
  }

  @override
  Future<String?> currentUrl() {
    return _webview.currentUrl;
  }

  @override
  Future<String> evaluateJavascript(String javascript) {
    return _webview.evaluateJavascript(javascript);
  }

  @override
  Future<int> getScrollX() {
    return _webview.getScrollX();
  }

  @override
  Future<int> getScrollY() {
    return _webview.getScrollY();
  }

  @override
  Future<String?> getTitle() {
    return _webview.currentTitle;
  }

  @override
  Future<void> goBack() {
    return _webview.goBack();
  }

  @override
  Future<void> goForward() {
    return _webview.goForward();
  }

  @override
  Future<void> loadFile(String absoluteFilePath) {
    // TODO: implement loadFile
    throw UnimplementedError();
  }

  @override
  Future<void> loadFlutterAsset(String key) {
    // TODO: implement loadFlutterAsset
    throw UnimplementedError();
  }

  @override
  Future<void> loadHtmlString(String html, {String? baseUrl}) {
    return _webview.loadHtmlString(html, baseUrl: baseUrl);
  }

  @override
  Future<void> loadRequest(WebViewRequest request) {
    return _webview.loadRequest(request.toJson());
  }

  @override
  Future<void> loadUrl(String url, Map<String, String>? headers) {
    return _webview.loadUrl(url, headers);
  }

  @override
  Future<void> reload() {
    return _webview.reload();
  }

  @override
  Future<void> removeJavascriptChannels(Set<String> javascriptChannelNames) {
    return _webview.removeJavascriptChannels(javascriptChannelNames);
  }

  @override
  Future<void> runJavascript(String javascript) {
    return _webview.evaluateJavascript(javascript);
  }

  @override
  Future<String> runJavascriptReturningResult(String javascript) {
    return _webview.evaluateJavascript(javascript);
  }

  @override
  Future<void> scrollBy(int x, int y) {
    // TODO: implement scrollTo
    throw UnimplementedError();
  }

  @override
  Future<void> scrollTo(int x, int y) {
    // TODO: implement scrollTo
    throw UnimplementedError();
  }

  Future<void> scrollDelta(Offset orignal, Offset delta) {
    return _webview.scrollDelta(orignal, delta);
  }

  @override
  Future<void> updateSettings(WebSettings setting) {
    // TODO: implement updateSettings
    throw UnimplementedError();
  }

  Future<void> setMouseClick(DesktopMousePointerButton button, bool isDown, Offset position) {
    return _webview.setMouseClick(button, isDown, position);
  }

  Future<int> textureId() {
    return _webview.textureId;
  }

  Future<void> initialize(int width, int height, String initialUrl) {
    return _webview.initialize(width, height, initialUrl);
  }

  Future<void> setWindowOpenPolicy(DesktopWebviewClientWindowOpenPolicy webviewClientWindowOpenPolicy) {
    return _webview.setWindowOpenPolicy(webviewClientWindowOpenPolicy);
  }

  Future<void> setWebviewSize(Size size) {
    return _webview.setViewSize(size);
  }

  Future<void> updateJavascriptChannels(Set<JavascriptChannel>? newChannels) {
    return _webview.updateJavascriptChannels(newChannels);
  }
}

==> flutter_webview_desktop-0.0.8-dev.tar.gz: lib/src/desktop_webview_platform_controller.dart <==
import 'dart:async';
import 'dart:ui';

import 'package:flutter/gestures.dart';
import 'package:webview_flutter_platform_interface/webview_flutter_platform_interface.dart';

import 'desktop_webview_controller.dart';
import 'desktop_webview_enums.dart';

DesktopMousePointerButton getDesktopButton(int value) {
  switch (value) {
    case kPrimaryMouseButton:
      return DesktopMousePointerButton.primary;
    case kSecondaryMouseButton:
      return DesktopMousePointerButton.secondary;
    case kTertiaryButton:
      return DesktopMousePointerButton.tertiary;
    default:
      return DesktopMousePointerButton.none;
  }
}

class DesktopWebviewController implements WebViewPlatformController {
  DesktopWebviewController(this._javascriptChannelRegistry) {
    _webview = DesktopWebview(_javascriptChannelRegistry);
  }
  late DesktopWebview _webview;
  final JavascriptChannelRegistry _javascriptChannelRegistry;

  DesktopWebview get webview => _webview;
  @override
  Future<void> addJavascriptChannels(Set<String> javascriptChannelNames) {
    return _webview.addJavascriptChannels(javascriptChannelNames);
  }

  @override
  Future<bool> canGoBack() {
    return _webview.canGoBack;
  }

  @override
  Future<bool> canGoForward() {
    return _webview.canGoForward;
  }

  @override
  Future<void> clearCache() {
    return _webview.clearCache();
  }

  @override
  Future<String?> currentUrl() {
    return _webview.currentUrl;
  }

  @override
  Future<String> evaluateJavascript(String javascript) {
    return _webview.evaluateJavascript(javascript);
  }

  @override
  Future<int> getScrollX() {
    return _webview.getScrollX();
  }

  @override
  Future<int> getScrollY() {
    return _webview.getScrollY();
  }

  @override
  Future<String?> getTitle() {
    return _webview.currentTitle;
  }

  @override
  Future<void> goBack() {
    return _webview.goBack();
  }

  @override
  Future<void> goForward() {
    return _webview.goForward();
  }

  @override
  Future<void> loadFile(String absoluteFilePath) {
    // TODO: implement loadFile
    throw UnimplementedError();
  }

  @override
  Future<void> loadFlutterAsset(String key) {
    // TODO: implement loadFlutterAsset
    throw UnimplementedError();
  }

  @override
  Future<void> loadHtmlString(String html, {String? baseUrl}) {
    return _webview.loadHtmlString(html, baseUrl: baseUrl);
  }

  @override
  Future<void> loadRequest(WebViewRequest request) {
    return _webview.loadRequest(request.toJson());
  }

  @override
  Future<void> loadUrl(String url, Map<String, String>? headers) {
    return _webview.loadUrl(url, headers);
  }

  @override
  Future<void> reload() {
    return _webview.reload();
  }

  @override
  Future<void> removeJavascriptChannels(Set<String> javascriptChannelNames) {
    return _webview.removeJavascriptChannels(javascriptChannelNames);
  }

  @override
  Future<void> runJavascript(String javascript) {
    return _webview.evaluateJavascript(javascript);
  }

  @override
  Future<String> runJavascriptReturningResult(String javascript) {
    return _webview.evaluateJavascript(javascript);
  }

  @override
  Future<void> scrollBy(int x, int y) {
    // TODO: implement scrollTo
    throw UnimplementedError();
  }

  @override
  Future<void> scrollTo(int x, int y) {
    // TODO: implement scrollTo
    throw UnimplementedError();
  }

  Future<void> scrollDelta(Offset orignal, Offset delta) {
    return _webview.scrollDelta(orignal, delta);
  }

  @override
  Future<void> updateSettings(WebSettings setting) {
    // TODO: implement updateSettings
    throw UnimplementedError();
  }

  Future<void> setMouseClick(DesktopMousePointerButton button, bool isDown, Offset position) {
    return _webview.setMouseClick(button, isDown, position);
  }

  Future<int> textureId() {
    return _webview.textureId;
  }

  Future<void> initialize(int width, int height, String initialUrl, double devicePixelRatio) {
    return _webview.initialize(width, height, initialUrl, devicePixelRatio);
  }

  Future<void> setWindowOpenPolicy(DesktopWebviewClientWindowOpenPolicy webviewClientWindowOpenPolicy) {
    return _webview.setWindowOpenPolicy(webviewClientWindowOpenPolicy);
  }

  Future<void> setWebviewSize(Size size, double devicePixelRatio) {
    return _webview.setViewSize(size, devicePixelRatio);
  }

  Future<void> updateJavascriptChannels(Set<JavascriptChannel>? newChannels) {
    return _webview.updateJavascriptChannels(newChannels);
  }
}
